@@ -3,6 +3,8 @@
 #' This method computes Bayes factors for comparing a model with an order restrictions on its parameters
 #' with the fully unrestricted model. \emph{Note that this method should only be used for confirmatory analyses}.
 #' \cr \cr
+#' \strong{For info on specifying correct priors for factors with more than 2 levels, see \href{https://easystats.github.io/bayestestR/articles/bayes_factors.html}{the Bayes factors vignette}.}
+#' \cr \cr
 #' For more info, see \href{https://easystats.github.io/bayestestR/articles/bayes_factors.html}{the Bayes factors vignette}.
 #'
 #' @param posterior A \code{stanreg} / \code{brmsfit} object, \code{emmGrid} or a data frame - representing a posterior distribution(s) from (see Details).
@@ -82,11 +84,11 @@
 #' # emmGrid objects
 #' # ---------------
 #' library(emmeans)
-#' options(contrasts = c("contr.bayes", "contr.bayes")) # see `bfrms` package
 #'
 #' # replicating http://bayesfactor.blogspot.com/2015/01/multiple-comparisons-with-bayesfactor-2.html
 #' disgust_data <- read.table(url("http://www.learnbayes.org/disgust_example.txt"), header = TRUE)
 #'
+#' contrasts(disgust_data$condition) <- contr.bayes # see vignette
 #' fit_model <- stan_glm(score ~ condition, data = disgust_data, family = gaussian())
 #'
 #' em_condition <- emmeans(fit_model, ~condition)
@@ -124,9 +126,10 @@ bayesfactor_restricted.stanreg <- function(posterior, hypothesis, prior = NULL,
 
   # Get Priors
   if (is.null(prior)) {
-    prior <- .update_to_priors(posterior, verbose = verbose)
+    prior <- posterior
   }
 
+  prior <- .update_to_priors(prior, verbose = verbose)
   prior <- insight::get_parameters(prior, effects = effects)
   posterior <- insight::get_parameters(posterior, effects = effects)
 
